@@ -37,6 +37,7 @@ public:
   bool with_comments = true;         // write comments
   bool with_history = true;          // write MTZ history in comments
   bool skip_empty = false;           // skip reflections with no values
+  bool skip_negative_sigi = false;   // skip refl. with sigma(I) < 0 in unmerged
   bool enable_UB = false;            // write _diffrn_orient_matrix.UB
   bool write_staraniso_tensor = true; // write _reflns.pdbx_aniso_B_tensor_*
   bool write_special_marker_for_pdb = false;
@@ -400,6 +401,8 @@ inline void remove_appendix_from_column_names(Mtz& mtz, std::ostream& out) {
       break;
     }
   }
+  if (appendix.empty())
+    return;
   out << "Ignoring '" << appendix << "' appended to column names.\n";
   for (Mtz::Column& col : mtz.columns) {
     size_t from_end  = appendix.size();
@@ -665,7 +668,11 @@ inline void MtzToCif::write_cif(const Mtz& mtz, const Mtz* mtz2,
 
   os << "\n\n_entry.id " << entry_id << "\n\n";
 
-  write_special_marker_if_requested(os, merged);
+  // If we have user-provided spec file, we don't take responsibility
+  // for the result. The spec in such case (write_special_marker_for_pdb==true)
+  // is used for merged data only, so we can add the marker in unmerged block.
+  if (spec_lines.empty() || !merged)
+    write_special_marker_if_requested(os, merged);
 
   std::vector<Trans> recipe;
   if (merged)
@@ -776,6 +783,9 @@ inline void MtzToCif::write_cif(const Mtz& mtz, const Mtz* mtz2,
   if (merged)
     write_main_loop(*merged, recipe, buf, os);
   if (unmerged) {
+    // if --depo flag is used, the spec file is for the merged data only
+    if (write_special_marker_for_pdb)
+      spec_lines.clear();
     prepare_recipe(*unmerged, recipe);
     write_main_loop(*unmerged, recipe, buf, os);
   }
@@ -785,7 +795,7 @@ inline void MtzToCif::write_main_loop(const Mtz& mtz, const std::vector<Trans>&
                                       char* buf, std::ostream& os) {
   // prepare indices
   std::vector<int> value_indices;  // used for --skip_empty
-  std::vector<int> sigma_indices;  // used for status 'x'
+  std::vector<int> sigma_indices;  // used for status 'x' and --skip-negative-sigi
   for (const Trans& tr : recipe) {
     if (tr.col_idx < 0)
       continue;
@@ -795,7 +805,7 @@ inline void MtzToCif::write_main_loop(const Mtz& mtz, const std::vector<Trans>&
                                   : is_in_list(col.label, skip_empty_cols))
         value_indices.push_back(tr.col_idx);
     }
-    if (col.type != 'Q' && col.type != 'L' && col.type != 'M')
+    if (col.type == 'Q' || col.type == 'L' || col.type == 'M')
       sigma_indices.push_back(tr.col_idx);
   }
 
@@ -858,6 +868,10 @@ inline void MtzToCif::write_main_loop(const Mtz& mtz, const std::vector<Trans>&
     int batch_number = 0;
     SweepData* sweep = nullptr;
     if (unmerged) {
+      if (skip_negative_sigi &&
+          std::any_of(sigma_indices.begin(), sigma_indices.end(),
+                      [&](int n) { return row[n] < 0; }))
+        continue;
       if (batch_idx == -1)
         fail("BATCH column not found");
       batch_number = (int) row[batch_idx];
@@ -1002,7 +1016,7 @@ inline void MtzToCif::write_cif_from_xds(const XdsAscii& xds, std::ostream& os)
   os << "\n_diffrn_refln.pdbx_image_id\n";
   int idx = 0;
   for (const XdsAscii::Refl& refl : xds.data) {
-    if (refl.sigma < 0)  // misfit
+    if (refl.sigma < 0 && skip_negative_sigi)  // misfit
       continue;
     char* ptr = buf;
     ptr += gf_snprintf(ptr, 128, "%d %d %d %d %d %g %.5g ",
@@ -1042,7 +1056,7 @@ inline void MtzToCif::write_cell_and_symmetry(const UnitCell& cell, double* rmsd
     WRITE("_cell.angle_gamma_esd %7.3f\n", rmsds[5]);
   if (sg) {
     os << "\n_symmetry.entry_id " << entry_id << "\n"
-          "_symmetry.space_group_name_H-M '" << sg->hm << "'\n"
+          "_symmetry.space_group_name_H-M '" << sg->pdb_name() << "'\n"
           "_symmetry.Int_Tables_number " << sg->number << '\n';
     // could write _symmetry_equiv.pos_as_xyz, but would it be useful?
   }
