@@ -81,19 +81,28 @@ struct NearestImage {
   double dist_sq;
   int pbc_shift[3] = { 0, 0, 0 };
   int sym_idx = 0;
+
   double dist() const { return std::sqrt(dist_sq); }
   bool same_asu() const {
     return pbc_shift[0] == 0 && pbc_shift[1] == 0 && pbc_shift[2] == 0 && sym_idx == 0;
   }
+
+  // return string such as 1555 or 1_555
   std::string symmetry_code(bool underscore) const {
     std::string s = std::to_string(sym_idx + 1);
     if (underscore)
       s += '_';
-    for (int i = 0; i < 3; ++i) {
-      if (std::abs(pbc_shift[i]) < 4)
-        s += char('5' + pbc_shift[i]);  // quick path
-      else
-        s += "(" + std::to_string(5 + pbc_shift[i]) + ")";
+    if (unsigned(5 + pbc_shift[0]) <= 9 &&
+        unsigned(5 + pbc_shift[1]) <= 9 &&
+        unsigned(5 + pbc_shift[2]) <= 9) {  // normal, quick path
+      for (int shift : pbc_shift)
+        s += char('5' + shift);
+    } else {                                // problematic, non-standard path
+      for (int i = 0; i < 3; ++i) {
+        if (i != 0 && underscore)
+          s += '_';
+        s += std::to_string(5 + pbc_shift[i]);
+      }
     }
     return s;
   }
@@ -121,6 +130,11 @@ struct NcsOp {
 // a synonym for convenient passing of hkl
 using Miller = std::array<int, 3>;
 
+struct MillerHash {
+  std::size_t operator()(const Miller& hkl) const noexcept {
+    return std::size_t((hkl[0] * 1024 + hkl[1]) * 1024 + hkl[2]);
+  }
+};
 
 struct UnitCell {
   UnitCell() = default;
@@ -161,6 +175,14 @@ struct UnitCell {
            eq(alpha, o.alpha) && eq(beta, o.beta) && eq(gamma, o.gamma);
   }
 
+  // compare lengths using relative tolerance rel, angles using tolerance deg
+  bool is_similar(const UnitCell& o, double rel, double deg) const {
+    auto siml = [&](double x, double y) { return std::fabs(x - y) < rel * std::max(x, y); };
+    auto sima = [&](double x, double y) { return std::fabs(x - y) < deg; };
+    return siml(a, o.a) && siml(b, o.b) && siml(c, o.c) &&
+           sima(alpha, o.alpha) && sima(beta, o.beta) && sima(gamma, o.gamma);
+  }
+
   void calculate_properties() {
     // ensure exact values for right angles
     double cos_alpha = alpha == 90. ? 0. : std::cos(rad(alpha));
