@@ -110,6 +110,14 @@ class TestSymmetry(unittest.TestCase):
         op2 = gemmi.Op('x/2+y/2,-a/2+k/2,z')
         self.assertEqual(op, op2)
 
+    def test_rot_type(self):
+        # examples taken from tst_sgtbx.py in cctbx
+        self.assertEqual(gemmi.Op('z,y,-x').rot_type(), 4)
+        self.assertEqual(gemmi.Op('x,y,z').rot_type(), 1)
+        self.assertEqual(gemmi.Op('2*x,y,z').rot_type(), 0)
+        self.assertEqual(gemmi.Op('-x,z-y,-y').rot_type(), -6)
+        self.assertEqual(gemmi.Op('-x,z-y,-y').inverse().rot_type(), -6)
+
     def test_generators_from_hall(self):
         # first test on example matrices from
         # http://cci.lbl.gov/sginfo/hall_symbols.html
@@ -137,7 +145,7 @@ class TestSymmetry(unittest.TestCase):
         self.assertEqual(len(gemmi_gops.sym_ops), cctbx_sg.order_p())
         self.assertEqual(len(gemmi_gops.cen_ops), cctbx_sg.n_ltr())
         self.assertEqual(len(gemmi_gops), cctbx_sg.order_z())
-        self.assertEqual(gemmi_gops.is_centric(), cctbx_sg.is_centric())
+        self.assertEqual(gemmi_gops.is_centrosymmetric(), cctbx_sg.is_centric())
         ctr = gemmi_gops.find_centering()
         self.assertEqual(ctr, cctbx_sg.conventional_centring_type_symbol())
         gemmi_triplets = set(m.triplet() for m in gemmi_gops)
@@ -168,10 +176,9 @@ class TestSymmetry(unittest.TestCase):
         for sg in gemmi.spacegroup_table():
             if sg.ccp4 != 0:
                 self.assertEqual(sg.ccp4 % 1000, sg.number)
-            if sg.operations().is_centric():
-                self.assertEqual(sg.laue_str(), sg.point_group_hm())
-            else:
-                self.assertNotEqual(sg.laue_str(), sg.point_group_hm())
+            is_laue = (sg.laue_str() == sg.point_group_hm())
+            self.assertEqual(sg.operations().is_centrosymmetric(), is_laue)
+            self.assertEqual(sg.is_centrosymmetric(), is_laue)
             if sgtbx:
                 hall = sg.hall.encode()
                 cctbx_sg = sgtbx.space_group(hall)
@@ -192,6 +199,17 @@ class TestSymmetry(unittest.TestCase):
             with self.assertRaises(StopIteration):
                 next(itb)
 
+    def test_symmorphic(self):
+        for sg in gemmi.spacegroup_table():
+            ops = sg.operations()
+            symmor_ops = ops.derive_symmorphic()
+            self.assertEqual(len(ops), len(symmor_ops))
+            symmor = gemmi.find_spacegroup_by_ops(symmor_ops)
+            self.assertTrue(symmor is not None)
+            self.assertTrue(symmor.is_symmorphic())
+            if sg.is_symmorphic():
+                self.assertEqual(sg.number, symmor.number)
+
     def test_find_spacegroup(self):
         self.assertEqual(gemmi.SpaceGroup('P21212').hm, 'P 21 21 2')
         self.assertEqual(gemmi.find_spacegroup_by_name('P21').hm, 'P 1 21 1')
@@ -231,6 +249,13 @@ class TestSymmetry(unittest.TestCase):
         self.assertEqual(len(gops), 4)
         self.assertEqual(gemmi.find_spacegroup_by_ops(gops).hm, 'C 1 c 1')
 
+    def test_add_inversion(self):
+        gops = gemmi.SpaceGroup(1).operations()
+        self.assertTrue(gops.add_inversion())
+        self.assertEqual(len(gops), 2)
+        self.assertEqual(gops.sym_ops, [gemmi.Op(), gemmi.Op('-x,-y,-z')])
+        self.assertFalse(gops.add_inversion())
+
     def change_basis(self, name_a, name_b, basisop_triplet):
         basisop = gemmi.Op(basisop_triplet)
         a = gemmi.find_spacegroup_by_name(name_a)
